@@ -10,6 +10,7 @@ from baangt.TestSteps.AddressCreation import AddressCreate
 from baangt.base.PDFCompare import PDFCompare, PDFCompareDetails
 from baangt.base.Faker import Faker as baangtFaker
 from baangt.base.Utils import utils
+from baangt.base.RuntimeStatistics import Statistic
 
 logger = logging.getLogger("pyC")
 
@@ -23,7 +24,7 @@ class TestStepMaster:
         self.ifActive = False
         self.ifIsTrue = True
         self.baangtFaker = None
-
+        self.statistics = Statistic()
         self.kwargs = kwargs
         self.testRunInstance = kwargs.get(GC.KWARGS_TESTRUNINSTANCE)
         self.testcaseDataDict = kwargs.get(GC.KWARGS_DATA)
@@ -55,6 +56,8 @@ class TestStepMaster:
                 # having done anything
                 self.teardown()
 
+        self.statistics.update_teststep_sequence()
+
     def executeDirect(self, executionCommands):
         """
         Executes a sequence of Commands. Will be subclassed in other modules.
@@ -63,6 +66,9 @@ class TestStepMaster:
         """
         for index, (key, command) in enumerate(executionCommands.items()):
             self.executeDirectSingle(index, command)
+            # self.statistics.update_teststep()  --> Moved to BrowserHandling into the activities themselves,
+            # so that we can also count for externally (subclassed) activitis
+
 
     def executeDirectSingle(self, commandNumber, command):
         """
@@ -151,7 +157,7 @@ class TestStepMaster:
         elif lActivity == "CLICKIF":
             self.browserSession.findByAndClickIf(xpath=xpath, css=css, id=id, timeout=lTimeout, value=lValue)
         elif lActivity == "PAUSE":
-            self.browserSession.sleep(sleepTimeinSeconds=float(lValue))
+            self.browserSession.sleep(seconds=float(lValue))
         elif lActivity == "IF":
             if self.ifActive:
                 raise BaseException("No nested IFs at this point, sorry...")
@@ -209,6 +215,8 @@ class TestStepMaster:
             self.doPDFComparison(lValue)
         elif lActivity == 'CHECKLINKS':
             self.checkLinks()
+        elif lActivity == 'ALERTIF':
+            self.browserSession.confirmAlertIfAny()
         else:
             raise BaseException(f"Unknown command in TestStep {lActivity}")
 
