@@ -4,7 +4,7 @@ VIGOGFNUMMER = "GF#"
 SAPPOLNR = "SAP Polizzennr"
 PRAEMIE = "Prämie"
 POLNRHOST = "PolNR Host"
-VERMITTLER = "vermittler"
+VERMITTLER = "Vermittler"
 MANDANT = "Mandant"
 DONAU = "DON"
 WSTV = "WSTV"
