@@ -3,7 +3,6 @@ import logging
 import json
 import baangt.base.GlobalConstants as GC
 from baangt.base.Timing.Timing import Timing
-import sys
 from baangt.base.Utils import utils
 from pathlib import Path
 from typing import Optional
@@ -13,16 +12,14 @@ from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from baangt.base.DataBaseORM import DATABASE_URL, TestrunLog, TestCaseSequenceLog
 from baangt.base.DataBaseORM import TestCaseLog, TestCaseField, GlobalAttribute, TestCaseNetworkInfo
-from baangt.base.PathManagement import ManagedPaths
 from datetime import datetime
 from sqlite3 import IntegrityError
-import time
 from baangt import plugin_manager
 import re
 import csv
 from dateutil.parser import parse
-import os
 from uuid import uuid4
+from pathlib import Path
 
 logger = logging.getLogger("pyC")
 
@@ -37,7 +34,7 @@ class ExportResults:
         self.networkInfo = self._get_network_info(kwargs.get('networkInfo'))
         self.testRunName = self.testRunInstance.testRunName
         self.dataRecords = self.testRunInstance.dataRecords
-        self.stage = self.testRunInstance.globalSettings.get('TC.Stage')
+        self.stage = self.__getStageFromDataRecordsOrGlobalSettings()
 
         try:
             self.exportFormat = kwargs.get(GC.KWARGS_TESTRUNATTRIBUTES).get(GC.EXPORT_FORMAT)
@@ -100,6 +97,22 @@ class ExportResults:
                 lExport = ExportAdditionalDataIntoTab(tabname=key, valueDict=value, outputExcelSheet=self.workbook)
                 lExport.export()
 
+    def __getStageFromDataRecordsOrGlobalSettings(self):
+        """
+        If "STAGE" is not provided in the data fields (should actually not happen, but who knows),
+        we shall take it from GlobalSettings. If also not there, take the default Value GC.EXECUTIN_STAGE_TEST
+        :return:
+        """
+        value = None
+        for key, value in self.dataRecords.items():
+            break
+        if not value.get(GC.EXECUTION_STAGE):
+            stage = self.testRunInstance.globalSettings.get('TC.Stage', GC.EXECUTION_STAGE_TEST)
+        else:
+            stage = value.get(GC.EXECUTION_STAGE)
+
+        return stage
+
     # -- API support --
     def getSummary(self):
         #
@@ -128,7 +141,7 @@ class ExportResults:
         Writes CSV-File of datarecords
 
         """
-        f = open(self.fileName, 'w')
+        f = open(self.fileName, 'w', encoding='utf-8-sig', newline='')
         writer = csv.DictWriter(f, self.dataRecords[0].keys())
         writer.writeheader()
         for i in range(0, len(self.dataRecords) - 1):
@@ -170,8 +183,8 @@ class ExportResults:
             id=self.testRunInstance.uuid.bytes,
             testrunName=self.testRunName,
             logfileName=logger.handlers[1].baseFilename,
-            startTime=datetime.strptime(start, "%H:%M:%S"),
-            endTime=datetime.strptime(end, "%H:%M:%S"),
+            startTime=datetime.strptime(start, "%d-%m-%Y %H:%M:%S"),
+            endTime=datetime.strptime(end, "%d-%m-%Y %H:%M:%S"),
             statusOk=success,
             statusFailed=error,
             statusPaused=waiting,
@@ -445,8 +458,12 @@ class ExportResults:
                 f'looks like we have no data in records: {self.dataRecords}, len of dataRecords: {len(self.dataRecords)}')
 
         # They are added here, because they'll not necessarily appear in the first record of the export data:
-        self.fieldListExport.append(GC.TESTCASEERRORLOG)
-        self.fieldListExport.append(GC.SCREENSHOTS)
+        if not GC.TESTCASEERRORLOG in self.fieldListExport:
+            self.fieldListExport.append(GC.TESTCASEERRORLOG)
+        if not GC.SCREENSHOTS in self.fieldListExport:
+            self.fieldListExport.append(GC.SCREENSHOTS)
+        if not GC.EXECUTION_STAGE in self.fieldListExport:
+            self.fieldListExport.append(GC.EXECUTION_STAGE)
 
     def _exportData(self):
         for key, value in self.dataRecords.items():
@@ -504,15 +521,26 @@ class ExportResults:
         try:
             if type(testRecordDict[fieldName]) == list:
 
-                self.worksheet.insert_image(line, cellNumber, testRecordDict[fieldName][-1], {'x_scale': 0.05,
-                                                                                              'y_scale': 0.05})
+                if Path(testRecordDict[fieldName][-1]).exists():
+                    self.worksheet.insert_image(line, cellNumber, testRecordDict[fieldName][-1], {'x_scale': 0.05,
+                                                                                                  'y_scale': 0.05})
+                else:
+                    logger.error(f"Sceenshot file {testRecordDict[fieldName][-1]} can't be found")
+
                 for nextScreenshotNumber in range(len(testRecordDict[fieldName]) - 1):
-                    self.worksheet.insert_image(line, len(self.fieldListExport) + nextScreenshotNumber + 1,
-                                                testRecordDict[fieldName][nextScreenshotNumber],
-                                                {'x_scale': 0.05, 'y_scale': 0.05})
+                    if Path(testRecordDict[fieldName][nextScreenshotNumber]).exists():
+                        self.worksheet.insert_image(line, len(self.fieldListExport) + nextScreenshotNumber + 1,
+                                                    testRecordDict[fieldName][nextScreenshotNumber],
+                                                    {'x_scale': 0.05, 'y_scale': 0.05})
+                    else:
+                        logger.error(f"Screenshot file {testRecordDict[fieldName][nextScreenshotNumber]} can't be found")
             else:
-                self.worksheet.insert_image(line, cellNumber, testRecordDict[fieldName], {'x_scale': 0.05,
-                                                                               'y_scale': 0.05})
+                if Path(testRecordDict[fieldName]).exists():
+                    self.worksheet.insert_image(line, cellNumber, testRecordDict[fieldName], {'x_scale': 0.05,
+                                                                                              'y_scale': 0.05})
+                else:
+                    logger.error(f"Screenshot file {testRecordDict[fieldName]} can't be found")
+
         except Exception as e:
             logger.error(f"Problem with screenshots - can't attach them {e}")
 
